@@ -167,6 +167,9 @@ int main(int argc, char *argv[])
     dAppNew->setMainWindow(&w);
     Dtk::Widget::moveToCenter(&w);
 
+    // show()会重置标题栏显示状态，根据缓存状态重新设置标题栏是否可见
+    w.titlebar()->setVisible(w.isTitleBarVisible());
+
 //#if (DTK_VERSION >= DTK_VERSION_CHECK(5, 5, 0, 0))
 //    dAppNew->ignoreVirtualKeyboard(&w); //禁止虚拟键盘顶起主界面标题栏（DTK5.5有效）
 //#endif
