@@ -40,6 +40,7 @@
 #include "movieservice.h"
 #include "imageviewer.h"
 #include "imageengine.h"
+#include "widgets/dialogs/imgdeletedialog.h"
 
 bool bfirstopen = true;
 bool bfirstandviewimage = false;
@@ -65,6 +66,19 @@ const int ALBUMBTN_NORMAL_WIDTH = 90;
 
 }//namespace
 
+void DDialogEx::keyPressEvent(QKeyEvent *event)
+{
+    if (event->key() == Qt::Key_Escape)
+        return;
+
+    DDialog::keyPressEvent(event);
+}
+
+void DDialogEx::closeEvent(QCloseEvent *event)
+{
+    event->ignore();
+}
+
 using namespace utils::common;
 MainWindow::MainWindow()
     : m_iCurrentView(VIEW_ALLPIC)
@@ -268,10 +282,9 @@ void MainWindow::initUI()
 //初始化等待窗口
 void MainWindow::initWaitDialog()
 {
-    m_waitdailog = new DDialog(this);
-
-    m_waitdailog->setCloseButtonVisible(false);
-    m_waitdailog->setWindowModality(Qt::WindowModal);
+    m_waitdailog = new DDialogEx(this);
+    m_waitdailog->setWindowFlag(Qt::WindowCloseButtonHint, false);
+    m_waitdailog->setModal(true);
     m_waitdailog->setFixedSize(QSize(480, 93));
 
     m_waitlabel = new DLabel(m_waitdailog);
@@ -309,14 +322,11 @@ void MainWindow::initTitleBar()
     btnGroup->setExclusive(true);
     QHBoxLayout *pTitleBtnLayout = new QHBoxLayout();
 
-    m_pAllPicBtn = new DPushButton();
+    m_pAllPicBtn = new FlatButton();
     m_pAllPicBtn->setFocusPolicy(Qt::TabFocus);
     AC_SET_OBJECT_NAME(m_pAllPicBtn, Main_All_Picture_Button);
     AC_SET_ACCESSIBLE_NAME(m_pAllPicBtn, Main_All_Picture_Button);
 
-//    m_pAllPicBtn = new DSuggestButton();
-    m_pAllPicBtn->setFlat(true);
-//    m_pAllPicBtn->setFixedSize(80, 36);
     m_pAllPicBtn->setMaximumSize(110, 36);
     m_pAllPicBtn->setCheckable(true);
     m_pAllPicBtn->setChecked(true);
@@ -325,13 +335,11 @@ void MainWindow::initTitleBar()
     DFontSizeManager::instance()->bind(m_pAllPicBtn, DFontSizeManager::T6);
     pTitleBtnLayout->addWidget(m_pAllPicBtn);
 
-    m_pTimeBtn = new DPushButton();
+    m_pTimeBtn = new FlatButton();
     m_pTimeBtn->setFocusPolicy(Qt::TabFocus);
     AC_SET_OBJECT_NAME(m_pTimeBtn, Main_Time_Line_Button);
     AC_SET_ACCESSIBLE_NAME(m_pTimeBtn, Main_Time_Line_Button);
-//    m_pTimeBtn = new DSuggestButton();
-    m_pTimeBtn->setFlat(true);
-//    m_pTimeBtn->setFixedSize(60, 36);
+
     m_pTimeBtn->setMaximumSize(110, 36);
     m_pTimeBtn->setCheckable(true);
     m_pTimeBtn->setText(tr("Timelines"));
@@ -340,13 +348,11 @@ void MainWindow::initTitleBar()
     pTitleBtnLayout->addSpacing(-6);
     pTitleBtnLayout->addWidget(m_pTimeBtn);
 
-    m_pAlbumBtn = new DPushButton();
+    m_pAlbumBtn = new FlatButton();
     m_pAlbumBtn->setFocusPolicy(Qt::TabFocus);
     AC_SET_OBJECT_NAME(m_pAlbumBtn, Main_Album_Button);
     AC_SET_ACCESSIBLE_NAME(m_pAlbumBtn, Main_Album_Button);
-//    m_pAlbumBtn = new DSuggestButton();
-    m_pAlbumBtn->setFlat(true);
-//    m_pAlbumBtn->setFixedSize(60, 36);
+
     m_pAlbumBtn->setMaximumSize(90, 36);
     m_pAlbumBtn->setCheckable(true);
     m_pAlbumBtn->setText(tr("Albums"));
@@ -409,8 +415,14 @@ void MainWindow::initTitleBar()
     m_addImageBtn->setToolTip(tr("Import photos and videos"));
     m_addImageBtn->setFixedSize(QSize(36, 36));
     m_addImageBtn->setShortcut(QKeySequence(CTRLO_SHORTCUT));
+
     titlebar()->addWidget(m_addImageBtn, Qt::AlignRight);
 
+    // UI规范调整，“+”按钮应与系统按钮组间隔10px，因此添加一个10px宽空白部件隔开
+    QWidget *spaceWidget = new QWidget(this);
+    spaceWidget->setFixedSize(QSize(10, 36));
+    titlebar()->addWidget(spaceWidget, Qt::AlignRight);
+
     titlebar()->setIcon(QIcon::fromTheme("deepin-album"));
     titlebar()->setMenu(m_pTitleBarMenu);
     titlebar()->setFocusPolicy(Qt::FocusPolicy::NoFocus);
@@ -538,7 +550,7 @@ void MainWindow::initCentralWidget()
     connect(ImageEngine::instance(), &ImageEngine::sigUpdateCollectBtn, this, &MainWindow::updateCollectButton);
     connect(m_collect, &DIconButton::clicked, this, &MainWindow::onCollectButtonClicked);
 
-    //刷新收藏按钮
+    //处理看图-删除按钮
     connect(ImageEngine::instance(), &ImageEngine::sigDel, this, &MainWindow::onLibDel, Qt::DirectConnection);
     //获取所有自定义相册
     connect(ImageEngine::instance(), &ImageEngine::sigGetAlbumName, this, &MainWindow::onSendAlbumName);
@@ -1266,17 +1278,21 @@ void MainWindow::onSearchEditFinished()
             albumBtnClicked();
             // donothing
         } else {
+            if (COMMON_STR_CLASS == m_pAlbumview->m_currentAlbum)
+                return;
+
             if (COMMON_STR_RECENT_IMPORTED == m_pAlbumview->m_pLeftListView->getItemCurrentType()) {
                 emit dApp->signalM->sigSendKeywordsIntoALLPic(keywords, COMMON_STR_RECENT_IMPORTED);
-            }
-            //LMH0514,为了解决26092 【相册】【5.6.9.14】在我的收藏相册下无法搜索到收藏的照片，加入我的收藏枚举
-            else if (COMMON_STR_FAVORITES == m_pAlbumview->m_pLeftListView->getItemCurrentType()) {
+            } else if (COMMON_STR_CLASSDETAIL == m_pAlbumview->m_currentAlbum) {
+                emit dApp->signalM->sigSendKeywordsIntoALLPic(keywords, COMMON_STR_CLASSDETAIL, -1, m_pAlbumview->m_currentClassName);
+            } else if (COMMON_STR_FAVORITES == m_pAlbumview->m_pLeftListView->getItemCurrentType()) {
+                //LMH0514,为了解决26092 【相册】【5.6.9.14】在我的收藏相册下无法搜索到收藏的照片，加入我的收藏枚举
                 emit dApp->signalM->sigSendKeywordsIntoALLPic(keywords, COMMON_STR_FAVORITES, DBManager::SpUID::u_Favorite);
             } else if (COMMON_STR_CUSTOM == m_pAlbumview->m_pLeftListView->getItemCurrentType()) {
                 emit dApp->signalM->sigSendKeywordsIntoALLPic(keywords, m_pAlbumview->m_pLeftListView->getItemCurrentName(), m_pAlbumview->m_pLeftListView->getItemCurrentUID());
             }
 
-            m_pAlbumview->m_pRightStackWidget->setCurrentIndex(4);
+            m_pAlbumview->m_pRightStackWidget->setCurrentIndex(5);
             m_pAlbumview->restorePicNum();
         }
     }
@@ -1396,6 +1412,32 @@ void MainWindow::updateCollectButton()
 
 void MainWindow::onLibDel(QString path)
 {
+// image-editor 1.0.30以后高版本，添加删除确认逻辑处理
+#ifdef DELETE_CONFIRM
+    bool bConfirmDelete = false;
+    int count = 0;
+    QFileInfo infox(path);
+    if (infox.isSymLink()) {
+        infox = QFileInfo(infox.readLink());
+    }
+    //文件或者文件夹不可写
+    if (QFileInfo(infox.dir(), infox.dir().path()).isWritable()) {
+        count++;
+    }
+
+    ImgDeleteDialog *dialog = new ImgDeleteDialog(this, count, false);
+    dialog->setDisplayPosition(DAbstractDialog::Center);
+    dialog->setObjectName("deteledialog");
+    if (dialog->exec() > 0) {
+        // 通知看图，删除图片
+        ImageEngine::instance()->sigDeleteImage();
+        bConfirmDelete = true;
+    }
+
+    if (!bConfirmDelete)
+        return;
+#endif
+
     if (m_imageViewer == nullptr) {
         return;
     }
@@ -1538,7 +1580,7 @@ void MainWindow::onNewAPPOpen(qint64 pid, const QStringList &arguments)
 
 void MainWindow::onSigViewImage(const SignalManager::ViewInfo &info, OpenImgAdditionalOperation operation, bool isCustom, const QString &album, int UID)
 {
-    m_backIndex = info.viewMainWindowID;
+    m_backIndex = m_iCurrentView;
     auto finalUseAlbum = album;
 
     if (operation == Operation_NoOperation || operation == Operation_FullScreen) {
@@ -1579,6 +1621,8 @@ void MainWindow::onSigViewImage(const SignalManager::ViewInfo &info, OpenImgAddi
             m_imageViewer->startSlideShow(paths, info.path);
         }
         m_backIndex_fromFullScreen = info.viewMainWindowID;
+
+        m_backIndex_fromFullScreen = m_pCenterWidget->currentIndex();
         break;
     }
 
@@ -1664,17 +1708,27 @@ void MainWindow::waitImportantProcessBeforeExit()
     canExit = false;
 
     auto watcher = QtConcurrent::run([&canExit]() {
-        //1.1停止
-        ImageEngineApi::instance()->stopRotate();
-        ImageDataService::instance()->stopFlushThumbnail();
+        if (ImageEngineApi::instance()->isRotating()) {
+            //1.1停止
+            ImageEngineApi::instance()->stopRotate();
 
-        //1.2等待
-        ImageEngineApi::instance()->waitRotateStop();
-        ImageDataService::instance()->waitFlushThumbnailFinish();
+            //1.2等待
+            ImageEngineApi::instance()->waitRotateStop();
 
-        //1.3强制文件写入
-        std::system("sync");
+            //1.3强制文件写入
+            std::system("sync");
+        }
 
+        if (ImageDataService::instance()->readerIsRunning()) {
+            //1.1停止
+            ImageDataService::instance()->stopFlushThumbnail();
+
+            //1.2等待
+            ImageDataService::instance()->waitFlushThumbnailFinish();
+
+            //1.3强制文件写入
+            std::system("sync");
+        }
         canExit = true;
     });
 
@@ -2093,6 +2147,14 @@ void MainWindow::startMonitor(const QList<QStringList> &paths, const QStringList
     }
 }
 
+/**
+   @return 返回当前标题栏是否可见
+ */
+bool MainWindow::isTitleBarVisible() const
+{
+    return m_bTitleBarVisible;
+}
+
 void MainWindow::wheelEvent(QWheelEvent *event)
 {
     if (DApplication::keyboardModifiers() == Qt::ControlModifier) {
@@ -2107,11 +2169,13 @@ void MainWindow::wheelEvent(QWheelEvent *event)
 
 void MainWindow::setTitleBarHideden(bool hide)
 {
+    m_bTitleBarVisible = !hide;
+
     if (hide) {
-        titlebar()->setFixedHeight(0);
+        titlebar()->setVisible(false);
         setTitlebarShadowEnabled(false);
     } else {
-        titlebar()->setFixedHeight(50);
+        titlebar()->setVisible(true);
         setTitlebarShadowEnabled(true);
     }
 }
@@ -2145,7 +2209,9 @@ void MainWindow::onButtonClicked(int id)
         }
         albumBtnClicked();
         // 如果是最近删除或者移动设备,则搜索框不显示
-        if (2 == m_pAlbumview->m_pRightStackWidget->currentIndex() || 5 == m_pAlbumview->m_pRightStackWidget->currentIndex()) {
+        if (2 == m_pAlbumview->m_pRightStackWidget->currentIndex()
+                || 6 == m_pAlbumview->m_pRightStackWidget->currentIndex()
+                || (3 == m_pAlbumview->m_pRightStackWidget->currentIndex() && m_pAlbumview->m_currentType == COMMON_STR_CLASS)) {
             m_pSearchEdit->setVisible(false);
         } else {
 #ifdef tablet_PC
@@ -2183,10 +2249,12 @@ void MainWindow::onStartImprot()
 void MainWindow::onProgressOfWaitDialog(int allfiles, int completefiles)
 {
     QString countText = "";
-    if (m_bImport) {
+    if (Progress_Import == m_progressType) {
         countText  = QString(QObject::tr("%1/%2 items imported")).arg(completefiles).arg(allfiles);
-    } else {
+    } else if (Progress_Delete == m_progressType) {
         countText = QString(QObject::tr("%1/%2 items deleted")).arg(completefiles).arg(allfiles);
+    } else if (Progress_Classify == m_progressType) {
+        countText = QString(QObject::tr("%1/%2 items classifyed")).arg(completefiles).arg(allfiles);
     }
 
     m_countLabel->setText(countText);
@@ -2208,10 +2276,13 @@ void MainWindow::onPopupWaitDialog(QString waittext, bool bneedprogress)
         m_waitdailog->show();
     } else {
         if (waittext.compare(tr("Importing..."), Qt::CaseInsensitive) >= 0) {
-            m_bImport = true;
+            m_progressType = Progress_Import;
+        } else if (waittext.compare(tr("Classifying..."), Qt::CaseInsensitive) >= 0) {
+            m_progressType = Progress_Classify;
         } else {
-            m_bImport = false;
+            m_progressType = Progress_Delete;
         }
+
         m_waitlabel->move(40, 7);
         m_waitlabel->setText(waittext);
         m_importBar->show();
@@ -2222,9 +2293,9 @@ void MainWindow::onPopupWaitDialog(QString waittext, bool bneedprogress)
 
 void MainWindow::onCloseWaitDialog()
 {
-    m_bImport = false;
+    m_progressType = Progress_Unknown;
     m_countLabel->setText("");
-    m_waitdailog->close();
+    m_waitdailog->hide();
 }
 
 void MainWindow::onImagesRemoved()
@@ -2316,11 +2387,9 @@ void MainWindow::onAddImageBtnClicked(bool checked)
 
 void MainWindow::onHideFromFullScreen()
 {
-    if (VIEW_IMAGE != m_backIndex_fromFullScreen) {
-        setTitleBarHideden(false);
-    }
+    setTitleBarHideden(false);
 
-    m_pCenterWidget->setCurrentIndex(m_backIndex_fromFullScreen);
+    m_pCenterWidget->setCurrentIndex(m_backIndex);
 }
 
 void MainWindow::onExportImage(QStringList paths)
