@@ -36,6 +36,8 @@ namespace {
 const int ITEM_SPACING = 4;
 const int BASE_HEIGHT = 100;
 const int MINIMUN_WIDTH = 442;
+const int STATUSBAR_HEIGHT = 27;
+const int RIGHT_MARGIN = 13;
 
 // const QString IMAGE_DEFAULTTYPE = "All pics";
 const QString IMAGE_DEFAULTTYPE = "All Photos";
@@ -182,6 +184,7 @@ void ThumbnailListView::mousePressEvent(QMouseEvent *event)
     } else {
         setDragEnabled(false);
     }
+    m_pressed = event->pos();
 
     DListView::mousePressEvent(event);
 }
@@ -194,6 +197,10 @@ void ThumbnailListView::mouseMoveEvent(QMouseEvent *event)
         return;
     }
 
+    // 照片分类页面禁用框选
+    if (m_delegatetype == ThumbnailDelegate::AlbumViewClassType)
+        return;
+
     if (touchStatus == 0) {
         touchStatus = 1;
         activeClick = false;
@@ -232,12 +239,22 @@ void ThumbnailListView::showEvent(QShowEvent *event)
     Q_UNUSED(event);
     //时间线使用
     emit sigShowEvent();
-    int i_totalwidth = width() - 30;
+    int i_totalwidth = width() - RIGHT_MARGIN;
     //计算一行的个数
     m_rowSizeHint = i_totalwidth / (m_iBaseHeight + ITEM_SPACING);
     m_onePicWidth = (i_totalwidth - ITEM_SPACING * (m_rowSizeHint - 1)) / m_rowSizeHint;//一张图的宽度
 }
 
+void ThumbnailListView::hideEvent(QHideEvent *event)
+{
+    // 控件隐藏时，若有焦点，清空焦点，可以避免焦点自动跳转到下一控件
+    QWidget* fw = QApplication::focusWidget();
+    if (fw == this)
+        this->clearFocus();
+
+    DListView::hideEvent(event);
+}
+
 void ThumbnailListView::wheelEvent(QWheelEvent *event)
 {
     if (event->delta() < 0) {
@@ -271,6 +288,10 @@ void ThumbnailListView::sltReloadAfterFilterEnd(const QVector<DBImgInfo> &allIma
     for (int j = (m_model->rowCount() - 1); j < allImageDataVector.size(); j++) {
         insertThumbnail(allImageDataVector.at(j));
     }
+
+    // 添加底栏空白区域
+    insertBlankOrTitleItem(ItemTypeBlank, "", "", STATUSBAR_HEIGHT);
+
     //加载完后通知所有图片页刷新状态栏显示数量
     emit sigUpdatePicNum();
 }
@@ -293,6 +314,20 @@ void ThumbnailListView::mouseReleaseEvent(QMouseEvent *event)
         if (QApplication::keyboardModifiers() == Qt::NoModifier) {
             emit sigMouseRelease();
         }
+    } else if (COMMON_STR_CLASS  == m_imageType) {
+        if ((event->pos() - m_pressed).manhattanLength() > 3)
+            return;
+
+        if (event->button() == Qt::LeftButton) {
+            QModelIndex index = this->indexAt(event->pos());
+            DBImgInfo info = index.data(Qt::DisplayRole).value<DBImgInfo>();
+
+            // 点击进入分类详情页
+            if (!info.className.isEmpty())
+                emit dApp->signalM->sigOpenClassDetail(info.className);
+        }
+
+        return DListView::mouseReleaseEvent(event);
     } else {
         emit sigMouseRelease();
     }
@@ -469,6 +504,7 @@ QStringList ThumbnailListView::getFileList(int row, ItemType type)
     if (m_delegatetype == ThumbnailDelegate::AllPicViewType
             || m_delegatetype == ThumbnailDelegate::AlbumViewCustomType
             || m_delegatetype == ThumbnailDelegate::AlbumViewFavoriteType
+            || m_delegatetype == ThumbnailDelegate::AlbumViewClassDetailType
             || m_delegatetype == ThumbnailDelegate::SearchViewType
             || m_delegatetype == ThumbnailDelegate::AlbumViewPhoneType) {
         //遍历所有数据
@@ -532,6 +568,7 @@ QList<DBImgInfo> ThumbnailListView::getAllFileInfo(int row)
     if (m_delegatetype == ThumbnailDelegate::AllPicViewType
             || m_delegatetype == ThumbnailDelegate::AlbumViewCustomType
             || m_delegatetype == ThumbnailDelegate::AlbumViewFavoriteType
+            || m_delegatetype == ThumbnailDelegate::AlbumViewClassDetailType
             || m_delegatetype == ThumbnailDelegate::SearchViewType) {
         for (int i = 0; i < m_model->rowCount(); i++) {
             QModelIndex index = m_model->index(i, 0);
@@ -587,6 +624,10 @@ int ThumbnailListView::getRow(const QString &path)
 
 void ThumbnailListView::onShowMenu(const QPoint &pos)
 {
+    // 照片分类封面页，禁用右键菜单
+    if (COMMON_STR_CLASS == m_imageType)
+        return;
+
     //外接设备显示照片时，禁用鼠标右键菜单
     QModelIndex index = this->indexAt(pos);
     if (!index.isValid() || ALBUM_PATHTYPE_BY_PHONE == m_imageType) {
@@ -1090,6 +1131,12 @@ void ThumbnailListView::menuItemDeal(QStringList paths, QAction *action)
 
 void ThumbnailListView::onPixMapScale(int value)
 {
+    // 图片分类视图，封面大小固定为170像素
+    if (m_delegatetype == ThumbnailDelegate::AlbumViewClassType) {
+        m_iBaseHeight = 170;
+        resizeEventF();
+        return;
+    }
 //    if (!this->isVisible())
 //        return;
     switch (value) {
@@ -1159,6 +1206,7 @@ void ThumbnailListView::resizeEvent(QResizeEvent *e)
 
     resizeEventF();
 
+    this->verticalScrollBar()->setFixedHeight(this->height() - STATUSBAR_HEIGHT);
 //    if (m_model->rowCount() > 0) {
 //        for (int i = 0; i < m_model->rowCount(); i++) {
 //            QModelIndex index = m_model->index(i, 0);
@@ -1380,6 +1428,7 @@ void ThumbnailListView::updateThumbnailViewAfterDelete(const QStringList &paths)
     if (m_delegatetype == ThumbnailDelegate::AllPicViewType
             || m_delegatetype == ThumbnailDelegate::AlbumViewCustomType
             || m_delegatetype == ThumbnailDelegate::AlbumViewFavoriteType
+            || m_delegatetype == ThumbnailDelegate::AlbumViewClassDetailType
             || m_delegatetype == ThumbnailDelegate::TimeLineViewType
             || m_delegatetype == ThumbnailDelegate::AlbumViewImportTimeLineViewType) {
         for (int i = (m_model->rowCount() - 1); i >= 0; i--) {
@@ -1847,6 +1896,7 @@ void ThumbnailListView::showAppointTypeItem(ItemType type)
         emit sigNoPicOrNoVideo(false);
     }
 }
+
 //显示类型数量
 int ThumbnailListView::getAppointTypeItemCount(ItemType type)
 {
@@ -2186,7 +2236,7 @@ void ThumbnailListView::timeLimeFloatBtnClicked(const QString &date, bool isSele
 
 void ThumbnailListView::resizeEventF()
 {
-    int i_totalwidth = width() - 30;
+    int i_totalwidth = width() - RIGHT_MARGIN;
     //计算一行的个数
     m_rowSizeHint = i_totalwidth / (m_iBaseHeight + ITEM_SPACING);
     int currentwidth = (i_totalwidth - ITEM_SPACING * (m_rowSizeHint - 1)) / m_rowSizeHint;//一张图的宽度
