@@ -35,6 +35,8 @@
 #include <DDesktopServices>
 #include <QImageReader>
 #include <QMimeDatabase>
+#include <DSysInfo>
+DCORE_USE_NAMESPACE
 
 DWIDGET_USE_NAMESPACE
 
@@ -643,6 +645,33 @@ QFuture<void> multiLoadImage(const QStringList &paths)
     return watcher;
 }
 
+bool isSupportClassify(const QString &path)
+{
+    bool bRet = false;
+    //路径为空直接跳出
+    if (!path.isEmpty()) {
+        QMimeDatabase db;
+        QMimeType mt = db.mimeTypeForFile(path, QMimeDatabase::MatchContent);
+
+        if (mt.name().startsWith("image/") || mt.name().startsWith("video/x-mng")) {
+            if (!mt.name().startsWith("image/gif") && !mt.name().startsWith("image/tiff")) {
+                bRet = true;
+            }
+        }
+
+        if (!bRet) {
+            QMimeType mt1 = db.mimeTypeForFile(path, QMimeDatabase::MatchExtension);
+            if (mt1.name().startsWith("image/") || mt1.name().startsWith("video/x-mng")) {
+                if (!mt1.name().startsWith("image/gif") && !mt1.name().startsWith("image/tiff")) {
+                    bRet = true;
+                }
+            }
+        }
+    }
+
+    return bRet;
+}
+
 }  // namespace base
 
 }  // namespace utils
