@@ -130,7 +130,7 @@ void AlbumLeftTabItem::initUI()
     m_nameLabel->setFont(ft);
 //    DPalette pa = DApplicationHelper::instance()->palette(m_nameLabel);
 //    pa.setBrush(DPalette::Text, pa.color(DPalette::ToolTipText));
-    m_nameLabel->setForegroundRole(DPalette::TextTitle);
+    m_nameLabel->setForegroundRole(QPalette::WindowText);
 //    m_nameLabel->setPalette(pa);
     // 设置标签不显示多文本
     m_nameLabel->setTextFormat(Qt::PlainText);
@@ -165,7 +165,7 @@ void AlbumLeftTabItem::initUI()
         const int width = 24;
         pixmapMount = utils::base::renderSVG(":/resources/images/sidebar/normal/icon_exit_normal.svg", QSize(width, width));
         m_unMountBtn->setPixmap(pixmapMount);
-        pHBoxLayout->addWidget(m_unMountBtn); 
+        pHBoxLayout->addWidget(m_unMountBtn);
 
         //调整m_nameLabel、m_pLineEdit宽度
         QRect rect = m_nameLabel->geometry();
@@ -192,7 +192,7 @@ void AlbumLeftTabItem::initUI()
         AC_SET_ACCESSIBLE_NAME(m_nameLabel, Album_Fav_Label);
     } else {
         DFontSizeManager::instance()->bind(m_nameLabel, DFontSizeManager::T6, Qt::ElideRight);
-        m_nameLabel->Settext(elideFont.elidedText(m_albumNameStr, Qt::ElideRight, m_nameLabel->width()));
+        m_nameLabel->Settext(m_albumNameStr);
         AC_SET_OBJECT_NAME(m_nameLabel, m_albumNameStr);
         AC_SET_ACCESSIBLE_NAME(m_nameLabel, m_albumNameStr);
     }
@@ -235,10 +235,7 @@ void AlbumLeftTabItem::onCheckNameValid()
     if (OPE_MODE_RENAMEALBUM == m_opeMode || OPE_MODE_ADDRENAMEALBUM == m_opeMode) {
         //由于m_nameLabel->text()的值还是原来的值，此处修改为直接使用上面获取的lineedit的值
         newNameStr = AlbumCreateDialog::getNewAlbumName(newNameStr);
-        QFontMetrics elideFont(m_nameLabel->font());
-        //m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, 85));
-        m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, m_nameLabel->width()));
-        m_nameLabel->oldstr = newNameStr;
+        m_nameLabel->Settext(newNameStr);
         QFont ft;
         ft.setPixelSize(14);
 
@@ -252,9 +249,7 @@ void AlbumLeftTabItem::onCheckNameValid()
         emit dApp->signalM->sigUpdataAlbumRightTitle(m_albumNameStr);
     } else if (OPE_MODE_ADDNEWALBUM == m_opeMode) {
         QFontMetrics elideFont(m_nameLabel->font());
-        //m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, 85));
-        m_nameLabel->Settext(elideFont.elidedText(newNameStr, Qt::ElideRight, m_nameLabel->width()));
-        m_nameLabel->oldstr = newNameStr;
+        m_nameLabel->Settext(newNameStr);
         QFont ft;
         ft.setPixelSize(14);
 
@@ -371,7 +366,7 @@ void AlbumLeftTabItem::oriAlbumStatus()
     }
 
     pImageLabel->setPixmap(pixmap);
-    m_nameLabel->setForegroundRole(DPalette::TextTitle);
+    m_nameLabel->setForegroundRole(QPalette::WindowText);
 }
 
 void AlbumLeftTabItem::newAlbumStatus()
@@ -426,3 +421,9 @@ void AlbumLeftTabItem::mouseReleaseEvent(QMouseEvent *e)
 {
     Q_UNUSED(e)
 }
+
+void AlbumLeftTabItem::paintEvent(QPaintEvent *e)
+{
+    pImageLabel->setEnabled(this->isActiveWindow());
+    QWidget::paintEvent(e);
+}
