@@ -123,7 +123,7 @@ void BatchOperateWidget::sltListViewChanged()
     viewChangedFlushFlag = false;
 
     ExpansionPanel::FilteData data;
-    data.type = m_ToolButton->getFilteType();
+    data = m_ToolButton->getFilterData();
     sltCurrentFilterChanged(data);
 
     batchSelectChanged(false, true);
@@ -232,12 +232,7 @@ void BatchOperateWidget::sltSelectionChanged(const QItemSelection &selected, con
 {
     Q_UNUSED(selected)
     Q_UNUSED(deselected)
-    if (m_thumbnailListView->getAppointTypeSelectItemCount(ItemTypeNull) == 0) {
-        if (AlbumViewTrashType == m_operateType)
-            batchSelectChanged(true, false);
-        refreshBtnEnabled(true);
-        return;
-    }
+
     batchSelectChanged(true, false);
     refreshBtnEnabled();
     m_thumbnailListView->setFocus();
@@ -306,7 +301,8 @@ void BatchOperateWidget::initUI()
     //筛选按钮
     initDropdown();
     hb->addWidget(m_ToolButton);
-    m_ToolButton->setVisible(true);
+    m_ToolButton->setVisible(m_operateType != AlbumViewClassDetailType);
+
     //收藏
     m_collection = new DToolButton(this);
     m_collection->setToolTip(QObject::tr("Favorite"));
@@ -438,6 +434,7 @@ void BatchOperateWidget::initDropdown()
     data.text = QObject::tr("Videos");
     data.type = ItemType::ItemTypeVideo;
     m_expansionMenu->addNewButton(data);
+
 }
 
 void BatchOperateWidget::batchSelectChanged(bool isBatchSelect, bool disConnectSignal)
@@ -489,7 +486,8 @@ void BatchOperateWidget::batchSelectChanged(bool isBatchSelect, bool disConnectS
     } else {
         m_trashRecoveryBtn->setVisible(false);
         m_trashDeleteBtn->setVisible(false);
-        m_ToolButton->setVisible(true);
+        if (m_operateType != AlbumViewClassDetailType)
+            m_ToolButton->setVisible(true);
         //根据所有选中图片，更新收藏按钮状态
         m_collection->setVisible(false);
         m_leftRotate->setVisible(false);
