@@ -1,6 +1,8 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="es">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="es">
 <context>
-    <name/>
+    <name></name>
     <message>
         <source>Delete</source>
         <translation type="vanished">Borrar</translation>
@@ -165,6 +167,10 @@
         <source>The files will be permanently deleted after the days shown on them</source>
         <translation>Los archivos se borrarán permanentemente después de los días indicados en ellos</translation>
     </message>
+    <message>
+        <source>Image classification</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Application</name>
@@ -315,6 +321,10 @@
         <source>Restoring...</source>
         <translation>Restaurando…</translation>
     </message>
+    <message>
+        <source>Classifying...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgDeleteDialog</name>
@@ -326,26 +336,6 @@
         <source>Delete</source>
         <translation>Borrar</translation>
     </message>
-    <message>
-        <source>Are you sure you want to delete this photo from the album?</source>
-        <translation type="vanished">¿Está seguro que desea borrar esta foto del álbum?</translation>
-    </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation type="vanished"><numerusform>¿Estás seguro de que quieres eliminar %n foto de los álbumes?</numerusform><numerusform>¿Estás seguro de que quieres eliminar %n fotos de los álbumes?</numerusform></translation>
-    </message>
-    <message>
-        <source>Are you sure you want to delete this video from the album?</source>
-        <translation type="vanished">¿Estás seguro de que quieres eliminar este video del álbum?</translation>
-    </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation type="vanished"><numerusform>¿Estás seguro de que quieres eliminar %n vídeo de los álbumes?</numerusform><numerusform>¿Estás seguro de que quieres eliminar %n videos de los álbumes?</numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n items from albums?</source>
-        <translation type="vanished"><numerusform>¿Estás seguro de que quieres eliminar %n elemento de los álbumes?</numerusform><numerusform>¿Estás seguro de que quieres eliminar %n elementos de los álbumes?</numerusform></translation>
-    </message>
     <message>
         <source>Are you sure you want to permanently delete this file?</source>
         <translation>¿Está seguro de que quiere eliminar permanentemente este archivo?</translation>
@@ -410,15 +400,24 @@
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n foto</numerusform><numerusform>%n fotos</numerusform></translation>
+        <translation>
+            <numerusform>%n foto</numerusform>
+            <numerusform>%n fotos</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n video</numerusform><numerusform>%n videos</numerusform></translation>
+        <translation>
+            <numerusform>%n video</numerusform>
+            <numerusform>%n videos</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n items</source>
-        <translation><numerusform>%n elemento</numerusform><numerusform>%n elementos</numerusform></translation>
+        <translation>
+            <numerusform>%n elemento</numerusform>
+            <numerusform>%n elementos</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -672,6 +671,10 @@
         <source>Failed to restore %1 files: file name too long</source>
         <translation>Fallo al restaurar %1 archivos: el nombre del archivo es demasiado largo</translation>
     </message>
+    <message>
+        <source>Classifying...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -878,20 +881,65 @@
     </message>
     <message numerus="yes">
         <source>%n photos selected</source>
-        <translation><numerusform>%n foto seleccionada</numerusform><numerusform>%n fotos seleccionadas</numerusform></translation>
+        <translation>
+            <numerusform>%n foto seleccionada</numerusform>
+            <numerusform>%n fotos seleccionadas</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n videos selected</source>
-        <translation><numerusform>%n video seleccionado</numerusform><numerusform>%n videos seleccionados</numerusform></translation>
+        <translation>
+            <numerusform>%n video seleccionado</numerusform>
+            <numerusform>%n videos seleccionados</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n items selected</source>
-        <translation><numerusform>%n elemento seleccionado</numerusform><numerusform>%n elementos seleccionados</numerusform></translation>
+        <translation>
+            <numerusform>%n elemento seleccionado</numerusform>
+            <numerusform>%n elementos seleccionados</numerusform>
+        </translation>
     </message>
     <message>
         <source>%1 items imported, %2 items exist already</source>
         <translation>%1 elementos importados, %2 elementos ya existian</translation>
     </message>
+    <message>
+        <source>%1/%2 items classifyed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scenery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Food</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Humans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Animals</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scene</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plants</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchView</name>
@@ -913,7 +961,10 @@
     </message>
     <message numerus="yes">
         <source>%n videos found</source>
-        <translation><numerusform>%n video encontrado</numerusform><numerusform>%n videos encontrados</numerusform></translation>
+        <translation>
+            <numerusform>%n video encontrado</numerusform>
+            <numerusform>%n videos encontrados</numerusform>
+        </translation>
     </message>
     <message>
         <source>1 video found</source>
@@ -921,11 +972,17 @@
     </message>
     <message numerus="yes">
         <source>%n items found</source>
-        <translation><numerusform>%n elemento encontrado</numerusform><numerusform>%n elementos encontrados</numerusform></translation>
+        <translation>
+            <numerusform>%n elemento encontrado</numerusform>
+            <numerusform>%n elementos encontrados</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation><numerusform>%n foto encontrada</numerusform><numerusform>%n fotos encontradas</numerusform></translation>
+        <translation>
+            <numerusform>%n foto encontrada</numerusform>
+            <numerusform>%n fotos encontradas</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -940,11 +997,17 @@
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n foto</numerusform><numerusform>%n fotos</numerusform></translation>
+        <translation>
+            <numerusform>%n foto</numerusform>
+            <numerusform>%n fotos</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n video</numerusform><numerusform>%n videos</numerusform></translation>
+        <translation>
+            <numerusform>%n video</numerusform>
+            <numerusform>%n videos</numerusform>
+        </translation>
     </message>
     <message>
         <source>Importing: %1</source>
@@ -1050,15 +1113,24 @@
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n foto</numerusform><numerusform>%n fotos</numerusform></translation>
+        <translation>
+            <numerusform>%n foto</numerusform>
+            <numerusform>%n fotos</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n video</numerusform><numerusform>%n videos</numerusform></translation>
+        <translation>
+            <numerusform>%n video</numerusform>
+            <numerusform>%n videos</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n items</source>
-        <translation><numerusform>%n elemento</numerusform><numerusform>%n elementos</numerusform></translation>
+        <translation>
+            <numerusform>%n elemento</numerusform>
+            <numerusform>%n elementos</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -1152,4 +1224,4 @@
         <translation>Nombre</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
