@@ -1,6 +1,8 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="it">
 <context>
-    <name/>
+    <name></name>
     <message>
         <source>Delete</source>
         <translation type="vanished">Elimina</translation>
@@ -165,6 +167,10 @@
         <source>The files will be permanently deleted after the days shown on them</source>
         <translation>I file verranno eliminati definitivamente dopo i giorni indicati</translation>
     </message>
+    <message>
+        <source>Image classification</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Application</name>
@@ -256,19 +262,19 @@
     <name>DBManager</name>
     <message>
         <source>Screen Capture</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Camera</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Draw</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>(copy)</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -315,6 +321,10 @@
         <source>Restoring...</source>
         <translation>Ripristino in corso...</translation>
     </message>
+    <message>
+        <source>Classifying...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgDeleteDialog</name>
@@ -326,57 +336,37 @@
         <source>Delete</source>
         <translation>Elimina</translation>
     </message>
-    <message>
-        <source>Are you sure you want to delete this photo from the album?</source>
-        <translation type="vanished">Sei sicuro di eliminare questa foto dall&apos;album?</translation>
-    </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n immagini dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n immagini dall&apos;album?</numerusform></translation>
-    </message>
-    <message>
-        <source>Are you sure you want to delete this video from the album?</source>
-        <translation type="vanished">Sei sicuro di eliminare questo video dall&apos;album?</translation>
-    </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n video dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n video dall&apos;album?</numerusform></translation>
-    </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n items from albums?</source>
-        <translation type="vanished"><numerusform>Sicuro di voler eliminare %n elementi dall&apos;album?</numerusform><numerusform>Sicuro di voler eliminare %n elementi dall&apos;album?</numerusform></translation>
-    </message>
     <message>
         <source>Are you sure you want to permanently delete this file?</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>You cannot restore it any longer</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Are you sure you want to permanently delete %1 files?</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>You cannot restore them any longer</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Are you sure you want to delete this file locally?</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>You can restore it in the trash</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Are you sure you want to delete %1 files locally?</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>You can restore them in the trash</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -410,15 +400,24 @@
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n immagini</numerusform><numerusform>%n immagini</numerusform></translation>
+        <translation>
+            <numerusform>%n immagini</numerusform>
+            <numerusform>%n immagini</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n video</numerusform><numerusform>%n video</numerusform></translation>
+        <translation>
+            <numerusform>%n video</numerusform>
+            <numerusform>%n video</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n items</source>
-        <translation><numerusform>%n elementi</numerusform><numerusform>%n elementi</numerusform></translation>
+        <translation>
+            <numerusform>%n elementi</numerusform>
+            <numerusform>%n elementi</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -655,23 +654,27 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message>
         <source>Import folders</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Import interrupted</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Cannot add this path, please try another one</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>The path already exists</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Failed to restore %1 files: file name too long</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Classifying...</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -879,20 +882,65 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message numerus="yes">
         <source>%n photos selected</source>
-        <translation><numerusform>%n immagini selezionate</numerusform><numerusform>%n immagini selezionate</numerusform></translation>
+        <translation>
+            <numerusform>%n immagini selezionate</numerusform>
+            <numerusform>%n immagini selezionate</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n videos selected</source>
-        <translation><numerusform>%n video selezionati</numerusform><numerusform>%n video selezionati</numerusform></translation>
+        <translation>
+            <numerusform>%n video selezionati</numerusform>
+            <numerusform>%n video selezionati</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n items selected</source>
-        <translation><numerusform>%n elementi selezionati</numerusform><numerusform>%n elementi selezionati</numerusform></translation>
+        <translation>
+            <numerusform>%n elementi selezionati</numerusform>
+            <numerusform>%n elementi selezionati</numerusform>
+        </translation>
     </message>
     <message>
         <source>%1 items imported, %2 items exist already</source>
         <translation>%1 elementi importati, %2 elementi già presenti</translation>
     </message>
+    <message>
+        <source>%1/%2 items classifyed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scenery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Food</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Humans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Animals</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scene</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plants</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchView</name>
@@ -914,7 +962,10 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message numerus="yes">
         <source>%n videos found</source>
-        <translation><numerusform>%n video trovati</numerusform><numerusform>%n video trovati</numerusform></translation>
+        <translation>
+            <numerusform>%n video trovati</numerusform>
+            <numerusform>%n video trovati</numerusform>
+        </translation>
     </message>
     <message>
         <source>1 video found</source>
@@ -922,11 +973,17 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message numerus="yes">
         <source>%n items found</source>
-        <translation><numerusform>%n elementi trovati</numerusform><numerusform>%n elementi trovati</numerusform></translation>
+        <translation>
+            <numerusform>%n elementi trovati</numerusform>
+            <numerusform>%n elementi trovati</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n photos found</source>
-        <translation><numerusform>%n foto trovate</numerusform><numerusform>%n foto trovate</numerusform></translation>
+        <translation>
+            <numerusform>%n foto trovate</numerusform>
+            <numerusform>%n foto trovate</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -941,11 +998,17 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n immagini</numerusform><numerusform>%n immagini</numerusform></translation>
+        <translation>
+            <numerusform>%n immagini</numerusform>
+            <numerusform>%n immagini</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n video</numerusform><numerusform>%n video</numerusform></translation>
+        <translation>
+            <numerusform>%n video</numerusform>
+            <numerusform>%n video</numerusform>
+        </translation>
     </message>
     <message>
         <source>Importing: %1</source>
@@ -1051,15 +1114,24 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
     </message>
     <message numerus="yes">
         <source>%n photos</source>
-        <translation><numerusform>%n immagini</numerusform><numerusform>%n immagini</numerusform></translation>
+        <translation>
+            <numerusform>%n immagini</numerusform>
+            <numerusform>%n immagini</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n videos</source>
-        <translation><numerusform>%n video</numerusform><numerusform>%n video</numerusform></translation>
+        <translation>
+            <numerusform>%n video</numerusform>
+            <numerusform>%n video</numerusform>
+        </translation>
     </message>
     <message numerus="yes">
         <source>%n items</source>
-        <translation><numerusform>%n elementi</numerusform><numerusform>%n elementi</numerusform></translation>
+        <translation>
+            <numerusform>%n elementi</numerusform>
+            <numerusform>%n elementi</numerusform>
+        </translation>
     </message>
 </context>
 <context>
@@ -1153,4 +1225,4 @@ Localizzazione italiana a cura di Massimo A. Carofano</translation>
         <translation>Nome</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
