@@ -5,55 +5,51 @@
     <name></name>
     <message>
         <source>Delete</source>
-        <translation type="unfinished">हटाउनुहोस्</translation>
+        <translation type="obsolete">हटाउनुहोस्</translation>
     </message>
     <message>
         <source>Fullscreen</source>
-        <translation type="unfinished">पूर्णस्क्रीन</translation>
+        <translation type="obsolete">पूर्णस्क्रीन</translation>
     </message>
     <message>
         <source>Slide show</source>
-        <translation type="unfinished">स्लाइड शो</translation>
+        <translation type="obsolete">स्लाइड शो</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation type="unfinished">प्रतिलिपि / कपी </translation>
+        <translation type="obsolete">प्रतिलिपि / कपी </translation>
     </message>
     <message>
         <source>Favorite</source>
-        <translation type="unfinished">मनपर्ने</translation>
+        <translation type="obsolete">मनपर्ने</translation>
     </message>
     <message>
         <source>Rotate clockwise</source>
-        <translation type="unfinished">घडीको दिशामा घुमाउनुहोस्</translation>
+        <translation type="obsolete">घडीको दिशामा घुमाउनुहोस्</translation>
     </message>
     <message>
         <source>Rotate counterclockwise</source>
-        <translation type="unfinished">घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
+        <translation type="obsolete">घडिको उल्टो दिशामा घुमाउनुहोस्</translation>
     </message>
     <message>
         <source>Set as wallpaper</source>
-        <translation type="unfinished">वालपेपरको रूपमा सेट गर्नुहोस्</translation>
+        <translation type="obsolete">वालपेपरको रूपमा सेट गर्नुहोस्</translation>
     </message>
     <message>
         <source>Display in file manager</source>
-        <translation type="unfinished">फाइल म्यानेजरमा देखाउनु गर्नुहोस्</translation>
+        <translation type="obsolete">फाइल म्यानेजरमा देखाउनु गर्नुहोस्</translation>
     </message>
     <message>
         <source>Photo info</source>
-        <translation type="unfinished">फोटो जानकारी</translation>
+        <translation type="obsolete">फोटो जानकारी</translation>
     </message>
     <message>
         <source>Restore</source>
-        <translation type="unfinished">पुनर्स्थापना गर्नुहोस्</translation>
+        <translation type="obsolete">पुनर्स्थापना गर्नुहोस्</translation>
     </message>
     <message>
         <source>Export</source>
-        <translation type="unfinished">निर्यात</translation>
-    </message>
-    <message>
-        <source>Video info</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">निर्यात</translation>
     </message>
 </context>
 <context>
@@ -167,6 +163,10 @@
         <source>The files will be permanently deleted after the days shown on them</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Image classification</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>Application</name>
@@ -254,6 +254,25 @@
         <translation>पहिले नै अवस्थित छ। के तपाइँ यसलाई बदल्न चाहानुहुन्छ?</translation>
     </message>
 </context>
+<context>
+    <name>DBManager</name>
+    <message>
+        <source>Screen Capture</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Camera</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Draw</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>(copy)</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DeepinStorage</name>
     <message>
@@ -298,6 +317,10 @@
         <source>Restoring...</source>
         <translation>पुनर्स्थापना गर्दै ...</translation>
     </message>
+    <message>
+        <source>Classifying...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ImgDeleteDialog</name>
@@ -310,33 +333,36 @@
         <translation>हटाउनुहोस्</translation>
     </message>
     <message>
-        <source>Are you sure you want to delete this photo from the album?</source>
-        <translation>के तपाइँ पक्का हुनुहुन्छ कि तपाइँ यस फोटोलाई एल्बमबाट हटाउन चाहानुहुन्छ?</translation>
-    </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n photos from albums?</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-        </translation>
-    </message>
-    <message>
-        <source>Are you sure you want to delete this video from the album?</source>
+        <source>Are you sure you want to permanently delete this file?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n videos from albums?</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-        </translation>
+    <message>
+        <source>You cannot restore it any longer</source>
+        <translation type="unfinished"></translation>
     </message>
-    <message numerus="yes">
-        <source>Are you sure you want to delete %n items from albums?</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-        </translation>
+    <message>
+        <source>Are you sure you want to permanently delete %1 files?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You cannot restore them any longer</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete this file locally?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can restore it in the trash</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Are you sure you want to delete %1 files locally?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You can restore them in the trash</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -404,6 +430,10 @@
         <source>All photos and videos</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No photos or videos found</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>LeftListView</name>
@@ -617,6 +647,30 @@
         <source>Import photos and videos</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Import folders</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import interrupted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot add this path, please try another one</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The path already exists</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to restore %1 files: file name too long</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Classifying...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MetadataName</name>
@@ -846,6 +900,42 @@
         <source>%1 items imported, %2 items exist already</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1/%2 items classifyed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scenery</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Food</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Humans</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Animals</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scene</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Plants</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Items</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchView</name>
